@@ -109,10 +109,7 @@ class MarkupField(models.TextField):
                              "allowed values: %s" %
                              (name, ', '.join(self.markup_choices_list)))
 
-        # for South FakeORM compatibility: the frozen version of a
-        # MarkupField can't try to add a _rendered field, because the
-        # _rendered field itself is frozen as well. See introspection
-        # rules below.
+        # for migration compatibility, avoid adding rendered_field
         self.rendered_field = not kwargs.pop('rendered_field', False)
 
         super(MarkupField, self).__init__(verbose_name, name, **kwargs)
@@ -124,7 +121,10 @@ class MarkupField(models.TextField):
             markup_type_field = models.CharField(
                 max_length=30,
                 choices=choices, default=self.default_markup_type,
-                editable=self.markup_type_editable, blank=self.blank)
+                editable=self.markup_type_editable,
+                blank=False if self.default_markup_type else True,
+                null=False if self.default_markup_type else True,
+            )
             rendered_field = models.TextField(editable=False, null=self.null)
             markup_type_field.creation_counter = self.creation_counter + 1
             rendered_field.creation_counter = self.creation_counter + 2
@@ -173,19 +173,13 @@ class MarkupField(models.TextField):
         defaults.update(kwargs)
         return super(MarkupField, self).formfield(**defaults)
 
+    def to_python(self, value):
+        if isinstance(value, Markup):
+            return value
+        else:
+            return super(MarkupField, self).to_python(value)
+
 # register MarkupField to use the custom widget in the Admin
 from django.contrib.admin.options import FORMFIELD_FOR_DBFIELD_DEFAULTS
 FORMFIELD_FOR_DBFIELD_DEFAULTS[MarkupField] = {
     'widget': widgets.AdminMarkupTextareaWidget}
-
-# allow South to handle MarkupField smoothly
-try:
-    from south.modelsinspector import add_introspection_rules
-    # For a normal MarkupField, the add_rendered_field attribute is
-    # always True, which means no_rendered_field arg will always be
-    # True in a frozen MarkupField, which is what we want.
-    add_introspection_rules(rules=[
-        ((MarkupField, ), [], {'rendered_field': ['rendered_field', {}], })
-    ], patterns=['markupfield\.fields\.MarkupField'])
-except ImportError:
-    pass
